@@ -14,7 +14,7 @@
 
   You should have received a copy of the GNU General Public License
   along with this program; if not, write to the Free Software
-  Foundation, Inc., 59 Temple Place - Suite 330, Boston, MA  02111-1307, USA.
+  Foundation, Inc., 51 Franklin Street, Fifth Floor, Boston, MA  02110-1301, USA.
 
   */
 
@@ -83,12 +83,22 @@ void GameWidget::getButton (int button)
     feld->startAnimation ((Feld::Direction)button);
 }
 
+void GameWidget::doUndo ()
+{
+  feld->doUndo ();
+}
+
+void GameWidget::doRedo ()
+{
+  feld->doRedo ();
+}
+
 void GameWidget::gameOver(int moves) {
     KMessageBox::information(this, i18n("You solved level %1 with %2 moves!").arg(level).arg(moves), i18n("Congratulations"));
 
     KScoreDialog high(KScoreDialog::Name | KScoreDialog::Score, this);
-    high.setCaption(i18n("Level %1 Best Scores").arg(level));
-    high.setConfigGroup(QString("High Scores Level %1").arg(level));
+    high.setCaption(i18n("Level %1 Highscores").arg(level));
+    high.setConfigGroup(QString("Highscores Level %1").arg(level));
 
     KScoreDialog::FieldInfo scoreInfo;
 
@@ -163,6 +173,8 @@ GameWidget::GameWidget ( QWidget *parent, const char* name )
 
     connect (feld, SIGNAL (gameOver(int)), SLOT(gameOver(int)));
     connect (feld, SIGNAL (sendMoves(int)), SLOT(getMoves(int)));
+    connect (feld, SIGNAL (enableRedo(bool)), SIGNAL(enableRedo(bool)));
+    connect (feld, SIGNAL (enableUndo(bool)), SIGNAL(enableUndo(bool)));
 
     highScore = new KScoreDialog(KScoreDialog::Name | KScoreDialog::Score, this);
 
@@ -172,7 +184,7 @@ GameWidget::GameWidget ( QWidget *parent, const char* name )
 
     slay->addSpacing(10);
 
-    slay->addWidget(new QLabel(i18n("Best score:"), bg));
+    slay->addWidget(new QLabel(i18n("Highscore:"), bg));
 
     QFont headerFont = KGlobalSettings::generalFont();
     headerFont.setBold(true);
@@ -209,8 +221,8 @@ GameWidget::~GameWidget()
 void GameWidget::showHighscores ()
 {
     KScoreDialog high(KScoreDialog::Name | KScoreDialog::Score, this);
-    high.setCaption(i18n("Level %1 Best Scores").arg(level));
-    high.setConfigGroup(QString("Best Scores Level %1").arg(level));
+    high.setCaption(i18n("Level %1 Highscores").arg(level));
+    high.setConfigGroup(QString("Highscores Level %1").arg(level));
     high.exec();
 }
 
