@@ -14,7 +14,7 @@
 
   You should have received a copy of the GNU General Public License
   along with this program; if not, write to the Free Software
-  Foundation, Inc., 59 Temple Place - Suite 330, Boston, MA  02111-1307, USA.
+  Foundation, Inc., 51 Franklin Street, Fifth Floor, Boston, MA  02110-1301, USA.
 
   */
 
@@ -22,7 +22,6 @@
 #include <qlayout.h>
 
 #include <kglobal.h>
-#include <kkeydialog.h>
 #include <klocale.h>
 #include <ksimpleconfig.h>
 #include <kstandarddirs.h>
@@ -42,13 +41,19 @@ extern Options settings;
 void AtomTopLevel::createMenu()
 {
     KAction *act = KStdGameAction::highscores(main, SLOT(showHighscores()), actionCollection());
-    act->setText(i18n("Show &Best Scores"));
+    act->setText(i18n("Show &Highscores"));
     KStdGameAction::quit(this, SLOT(close()), actionCollection());
     KStdGameAction::restart(main, SLOT(restartLevel()), actionCollection());
 
-    KStdAction::keyBindings(this, SLOT(configkeys()), actionCollection());
     KStdAction::preferences(this, SLOT(configopts()), actionCollection());
 
+    undoAction = KStdGameAction::undo (main, SLOT(doUndo()), actionCollection());
+    redoAction = KStdGameAction::redo (main, SLOT(doRedo()), actionCollection());
+    undoAction->setEnabled(false);
+    redoAction->setEnabled(false);
+    connect (main, SIGNAL (enableRedo(bool)), SLOT(enableRedo(bool)));
+    connect (main, SIGNAL (enableUndo(bool)), SLOT(enableUndo(bool)));
+
     new KAction(i18n("Atom Up"), Key_Up, main, SLOT(moveUp()), actionCollection(), "atom_up");
     new KAction(i18n("Atom Down"), Key_Down, main, SLOT(moveDown()), actionCollection(), "atom_down");
     new KAction(i18n("Atom Left"), Key_Left, main, SLOT(moveLeft()), actionCollection(), "atom_left");
@@ -58,11 +63,6 @@ void AtomTopLevel::createMenu()
     new KAction(i18n("Previous Atom"), SHIFT+Key_Tab, main, SLOT(previousAtom()), actionCollection(), "prev_atom");
 }
 
-void AtomTopLevel::configkeys()
-{
-    KKeyDialog::configure(actionCollection(),this);
-}
-
 void AtomTopLevel::configopts()
 {
     (new ConfigBox(this, "Options"))->show();
@@ -93,7 +93,7 @@ AtomTopLevel::AtomTopLevel()
     initConfig();
     setCentralWidget(main);
 
-    createGUI();
+    setupGUI( KMainWindow::Save | Keys | Create );
 }
 
 AtomTopLevel::~AtomTopLevel()
@@ -106,4 +106,14 @@ bool AtomTopLevel::queryExit()
     return true;
 }
 
+void AtomTopLevel::enableRedo(bool enable)
+{
+    redoAction->setEnabled(enable);
+}
+
+void AtomTopLevel::enableUndo(bool enable)
+{
+    undoAction->setEnabled(enable);
+}
+
 #include "toplevel.moc"
