@@ -7,14 +7,14 @@
 #include <kdialogbase.h>
 #include <knuminput.h>
 #include <krandomsequence.h>
-#include <kdemacros.h>
+#include "lib/libksirtet_export.h"
 
 class Board;
 class Piece;
 
 
 //-----------------------------------------------------------------------------
-class KDE_EXPORT AIPiece
+class LIBKSIRTET_EXPORT AIPiece
 {
  public:
     AIPiece();
@@ -38,7 +38,7 @@ class KDE_EXPORT AIPiece
 };
 
 //-----------------------------------------------------------------------------
-class KDE_EXPORT AI : public QObject
+class LIBKSIRTET_EXPORT AI : public QObject
 {
  Q_OBJECT
  public:
@@ -103,7 +103,7 @@ class KDE_EXPORT AI : public QObject
 };
 
 //-----------------------------------------------------------------------------
-class KDE_EXPORT AIConfig : public QWidget
+class LIBKSIRTET_EXPORT AIConfig : public QWidget
 {
  Q_OBJECT
  public:
